# -*- coding: utf-8 -*-

DEFAULT_TOKEN = b"ThisIsAnInsecurePublicTokenDontUseIt"

DEFAULT_SALT = "Quisque vulputate nibh eros, vehicula sollicitudin neque pellentesque quis"

DEFAULT_LOGIN_PATH = 'ajaxlogin'

DEFAULT_NEW_TOKEN_PATH = 'ajaxtoken'
